@@ -2,7 +2,7 @@ import logging
 from pathlib import Path
 from typing import Any, List, Optional
 
-import pandas as pd
+import pandas
 from annofabapi.models import TaskPhase
 
 logger = logging.getLogger(__name__)
@@ -25,7 +25,7 @@ class Csv:
     # Private
     #############################################
 
-    def _write_csv(self, filename: str, df: pd.DataFrame) -> None:
+    def _write_csv(self, filename: str, df: pandas.DataFrame) -> None:
         """
         カンマ区切りでBOM UTF-8で書きこむ(Excelで開けるようにするため）
         Args:
@@ -42,7 +42,7 @@ class Csv:
 
     @staticmethod
     def _create_required_columns(
-        df: pd.DataFrame, prior_columns: List[Any], dropped_columns: Optional[List[Any]] = None
+        df: pandas.DataFrame, prior_columns: List[Any], dropped_columns: Optional[List[Any]] = None
     ) -> List[str]:
         remained_columns = list(df.columns.difference(prior_columns))
         all_columns = prior_columns + remained_columns
@@ -53,7 +53,7 @@ class Csv:
         return all_columns
 
     def write_inspection_list(
-        self, df: pd.DataFrame, dropped_columns: Optional[List[str]] = None, only_error_corrected: bool = True,
+        self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None, only_error_corrected: bool = True,
     ) -> None:
         """
         検査コメント一覧をTSVで出力する
@@ -92,7 +92,7 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
         self._write_csv(f"{self.short_project_id}-検査コメントlist-{suffix}.csv", df[required_columns])
 
-    def write_task_list(self, df: pd.DataFrame, dropped_columns: Optional[List[str]] = None) -> None:
+    def write_task_list(self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None) -> None:
         """
         タスク一覧をTSVで出力する
         Args:
@@ -156,7 +156,7 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
         self._write_csv(f"{self.short_project_id}-タスクlist.csv", df[required_columns])
 
-    def write_task_history_list(self, df: pd.DataFrame, dropped_columns: Optional[List[str]] = None) -> None:
+    def write_task_history_list(self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None) -> None:
         """
         タスク履歴一覧をCSVで出力する
 
@@ -188,7 +188,7 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
         self._write_csv(f"{self.short_project_id}-タスク履歴list.csv", df[required_columns])
 
-    def write_labor_list(self, df: pd.DataFrame, dropped_columns: Optional[List[str]] = None) -> None:
+    def write_labor_list(self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None) -> None:
         """
         労務管理一覧をCSVで出力する
 
@@ -217,7 +217,7 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
         self._write_csv(f"{self.short_project_id}-労務管理list.csv", df[required_columns])
 
-    def write_worktime_summary(self, df: pd.DataFrame) -> None:
+    def write_worktime_summary(self, df: pandas.DataFrame) -> None:
         """
         作業時間に関する集計結果をCSVで出力する。
 
@@ -263,12 +263,12 @@ class Csv:
         stat_acceptance_df["sum"] = df[columns_acceptance].sum().values
         stat_acceptance_df["column"] = stat_acceptance_df.index + "_ignored_auto_acceptance"
 
-        target_df = pd.concat([stat_df, stat_inspection_df, stat_acceptance_df])
+        target_df = pandas.concat([stat_df, stat_inspection_df, stat_acceptance_df])
         target_df = target_df[["column", "mean", "std", "min", "25%", "50%", "75%", "max", "count", "sum"]]
 
         self._write_csv(f"集計結果csv/{self.short_project_id}-集計-作業時間.csv", target_df)
 
-    def write_count_summary(self, df: pd.DataFrame) -> None:
+    def write_count_summary(self, df: pandas.DataFrame) -> None:
         """
         個数に関する集計結果をCSVで出力する。
 
@@ -277,7 +277,6 @@ class Csv:
 
         """
         columns = [
-            "task_count",
             "input_data_count",
             "annotation_count",
             "inspection_count",
@@ -290,7 +289,7 @@ class Csv:
 
         self._write_csv(f"集計結果csv/{self.short_project_id}-集計-個数.csv", target_df)
 
-    def write_task_count_summary(self, df: pd.DataFrame) -> None:
+    def write_task_count_summary(self, df: pandas.DataFrame) -> None:
         """
         タスク数の集計結果をCSVで出力する。
 
@@ -299,7 +298,6 @@ class Csv:
 
         """
         columns = [
-            "task_count",
             "annotator_is_changed",
             "inspector_is_changed",
             "acceptor_is_changed",
@@ -308,13 +306,13 @@ class Csv:
         ]
 
         sum_series = df[columns].sum()
-        sum_df = pd.DataFrame()
+        sum_df = pandas.DataFrame()
         sum_df["column"] = sum_series.index
         sum_df["count_if_true"] = sum_series.values
-
+        sum_df = sum_df.append({"column": "task_count", "count_if_true": len(df)}, ignore_index=True)
         self._write_csv(f"集計結果csv/{self.short_project_id}-集計-タスク数.csv", sum_df)
 
-    def write_member_list(self, df: pd.DataFrame, dropped_columns: Optional[List[str]] = None):
+    def write_member_list(self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None):
         """
         プロジェクトメンバ一覧をTSVで出力する
         Args:
@@ -347,7 +345,7 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
         self._write_csv(f"{self.short_project_id}-メンバlist.csv", df[required_columns])
 
-    def write_ラベルごとのアノテーション数(self, df: pd.DataFrame):
+    def write_ラベルごとのアノテーション数(self, df: pandas.DataFrame):
         """
         アノテーションラベルごとの個数を出力
         """
@@ -364,7 +362,7 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns=None)
         self._write_csv(f"{self.short_project_id}-タスクlist-ラベルごとのアノテーション数.csv", df[required_columns])
 
-    def write_教師付作業者別日毎の情報(self, df: pd.DataFrame):
+    def write_教師付作業者別日毎の情報(self, df: pandas.DataFrame):
         """
         ユーザごと、日毎の作業時間一覧をTSVで出力する. タスク一覧とは無関係。
         """
@@ -388,7 +386,7 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns=None)
         self._write_csv(f"{self.short_project_id}_教師付者_教師付開始日list.csv", df[required_columns])
 
-    def write_ユーザ別日毎の作業時間(self, df: pd.DataFrame):
+    def write_ユーザ別日毎の作業時間(self, df: pandas.DataFrame):
         """
         ユーザごと、日毎の作業時間一覧をTSVで出力する. タスク一覧とは無関係。
         """
@@ -408,19 +406,19 @@ class Csv:
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns=None)
         self._write_csv(f"{self.short_project_id}-ユーザ_日付list-作業時間.csv", df[required_columns])
 
-    def write_メンバー別作業時間平均_画像1枚あたり(self, df: pd.DataFrame, phase: TaskPhase):
+    def write_メンバー別作業時間平均_画像1枚あたり(self, df: pandas.DataFrame, phase: TaskPhase):
         if len(df) == 0:
             logger.info(f"メンバー別画像1枚当たりの作業時間平均-{phase.value} 一覧が0件のため、出力しない")
             return
         self._write_csv(f"画像1枚当たり作業時間/{self.short_project_id}_画像1枚当たり作業時間_{phase.value}.csv", df)
 
-    def write_メンバー別作業時間平均_タスク1個あたり(self, df: pd.DataFrame, phase: TaskPhase):
+    def write_メンバー別作業時間平均_タスク1個あたり(self, df: pandas.DataFrame, phase: TaskPhase):
         if len(df) == 0:
             logger.info(f"メンバ別タスク1個当たりの作業時間平均-{phase.value} 一覧が0件のため、出力しない")
             return
         self._write_csv(f"タスク1個当たり作業時間/{self.short_project_id}_タスク1個当たり作業時間_{phase.value}.csv", df)
 
-    def write_productivity_from_aw_time(self, df: pd.DataFrame, dropped_columns: Optional[List[str]] = None):
+    def write_productivity_from_aw_time(self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None):
         """
         メンバごとの生産性を出力する。
 
@@ -435,9 +433,9 @@ class Csv:
         def get_phase_list() -> List[str]:
             columns = list(df.columns)
             phase_list = [TaskPhase.ANNOTATION.value, TaskPhase.INSPECTION.value, TaskPhase.ACCEPTANCE.value]
-            if ("annofab_worktime_hour", TaskPhase.INSPECTION.value) not in columns:
+            if ("monitored_worktime_hour", TaskPhase.INSPECTION.value) not in columns:
                 phase_list.remove(TaskPhase.INSPECTION.value)
-            if ("annofab_worktime_hour", TaskPhase.ACCEPTANCE.value) not in columns:
+            if ("monitored_worktime_hour", TaskPhase.ACCEPTANCE.value) not in columns:
                 phase_list.remove(TaskPhase.ACCEPTANCE.value)
             return phase_list
 
@@ -449,10 +447,10 @@ class Csv:
 
         user_columns = [("user_id", ""), ("username", ""), ("biography", "")]
 
-        annofab_worktime_columns = (
-            [("annofab_worktime_hour", phase) for phase in phase_list]
-            + [("annofab_worktime_hour", "sum")]
-            + [("annofab_worktime_ratio", phase) for phase in phase_list]
+        monitored_worktime_columns = (
+            [("monitored_worktime_hour", phase) for phase in phase_list]
+            + [("monitored_worktime_hour", "sum")]
+            + [("monitored_worktime_ratio", phase) for phase in phase_list]
         )
         production_columns = (
             [("task_count", phase) for phase in phase_list]
@@ -460,15 +458,15 @@ class Csv:
             + [("annotation_count", phase) for phase in phase_list]
         )
 
-        annowork_worktime_columns = [("annowork_worktime_hour", "sum")] + [
-            ("prediction_annowork_worktime_hour", phase) for phase in phase_list
+        actual_worktime_columns = [("actual_worktime_hour", "sum")] + [
+            ("prediction_actual_worktime_hour", phase) for phase in phase_list
         ]
 
         productivity_columns = (
-            [("annofab_worktime/input_data_count", phase) for phase in phase_list]
-            + [("annowork_worktime/input_data_count", phase) for phase in phase_list]
-            + [("annofab_worktime/annotation_count", phase) for phase in phase_list]
-            + [("annowork_worktime/annotation_count", phase) for phase in phase_list]
+            [("monitored_worktime/input_data_count", phase) for phase in phase_list]
+            + [("actual_worktime/input_data_count", phase) for phase in phase_list]
+            + [("monitored_worktime/annotation_count", phase) for phase in phase_list]
+            + [("actual_worktime/annotation_count", phase) for phase in phase_list]
         )
 
         inspection_comment_columns = [
@@ -479,11 +477,54 @@ class Csv:
 
         prior_columns = (
             user_columns
-            + annofab_worktime_columns
+            + monitored_worktime_columns
             + production_columns
-            + annowork_worktime_columns
+            + actual_worktime_columns
             + productivity_columns
             + inspection_comment_columns
         )
         required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
         self._write_csv(f"{self.short_project_id}-メンバごとの生産性と品質.csv", df[required_columns])
+
+    def write_whole_productivity_per_date(
+        self, df: pandas.DataFrame, dropped_columns: Optional[List[str]] = None
+    ) -> None:
+        """
+        日毎の全体の生産量、生産性を出力する。
+
+        Args:
+            df:
+            dropped_columns:
+
+
+        """
+        production_columns = [
+            "task_count",
+            "input_data_count",
+            "annotation_count",
+        ]
+        worktime_columns = [
+            "actual_worktime_hour",
+            "monitored_worktime_hour",
+            "monitored_annotation_worktime_hour",
+            "monitored_inspection_worktime_hour",
+            "monitored_acceptance_worktime_hour",
+        ]
+
+        velocity_columns = [
+            f"{numerator}/{denominator}{suffix}"
+            for numerator in ["actual_worktime_hour", "monitored_worktime_hour"]
+            for denominator in ["task_count", "input_data_count", "annotation_count"]
+            for suffix in ["", "__lastweek"]
+        ]
+
+        prior_columns = (
+            ["date", "cumsum_task_count", "cumsum_input_data_count", "cumsum_actual_worktime_hour"]
+            + production_columns
+            + worktime_columns
+            + velocity_columns
+            + ["working_user_count"]
+        )
+
+        required_columns = self._create_required_columns(df, prior_columns, dropped_columns)
+        self._write_csv(f"{self.short_project_id}-日毎の生産量と生産性.csv", df[required_columns])
