@@ -5,7 +5,7 @@ from pathlib import Path
 from typing import Any, Callable, Dict, List, Optional
 
 import annofabapi
-import pandas as pd
+import pandas
 from annofabapi.models import ProjectMemberRole, TaskPhase
 
 import annofabcli
@@ -50,13 +50,13 @@ def catch_exception(function: Callable[..., Any]) -> Callable[..., Any]:
 
 
 class WriteCsvGraph:
-    task_df: Optional[pd.DataFrame] = None
-    annotation_df: Optional[pd.DataFrame] = None
-    account_statistics_df: Optional[pd.DataFrame] = None
-    df_by_date_user: Optional[pd.DataFrame] = None
-    task_history_df: Optional[pd.DataFrame] = None
-    labor_df: Optional[pd.DataFrame] = None
-    productivity_df: Optional[pd.DataFrame] = None
+    task_df: Optional[pandas.DataFrame] = None
+    annotation_df: Optional[pandas.DataFrame] = None
+    account_statistics_df: Optional[pandas.DataFrame] = None
+    df_by_date_user: Optional[pandas.DataFrame] = None
+    task_history_df: Optional[pandas.DataFrame] = None
+    labor_df: Optional[pandas.DataFrame] = None
+    productivity_df: Optional[pandas.DataFrame] = None
 
     def __init__(self, table_obj: Table, output_dir: Path, project_id: str):
         self.table_obj = table_obj
@@ -133,7 +133,8 @@ class WriteCsvGraph:
         ユーザごとにプロットした散布図を出力する。
         """
         productivity_df = self._get_productivity_df()
-        catch_exception(self.scatter_obj.write_scatter_for_productivity)(productivity_df)
+        catch_exception(self.scatter_obj.write_scatter_for_productivity_by_monitored_worktime)(productivity_df)
+        catch_exception(self.scatter_obj.write_scatter_for_productivity_by_actual_worktime)(productivity_df)
         catch_exception(self.scatter_obj.write_scatter_for_quality)(productivity_df)
 
     def write_linegraph_for_task_overall(self) -> None:
@@ -202,6 +203,15 @@ class WriteCsvGraph:
         member_df = self.table_obj.create_member_df(task_df)
         catch_exception(self.csv_obj.write_member_list)(member_df)
 
+    def write_whole_productivity_csv_per_date(self) -> None:
+        """
+        日毎の生産性を出力する
+        """
+        task_df = self._get_task_df()
+        labor_df = self._get_labor_df()
+        whole_productivity_df = self.table_obj.create_whole_productivity_per_date(task_df, labor_df)
+        catch_exception(self.csv_obj.write_whole_productivity_per_date)(whole_productivity_df)
+
     def _write_メンバー別作業時間平均_画像1枚あたり_by_phase(self, phase: TaskPhase):
         df_by_inputs = self.table_obj.create_worktime_per_image_df(AggregationBy.BY_INPUTS, phase)
         self.csv_obj.write_メンバー別作業時間平均_画像1枚あたり(df_by_inputs, phase)
@@ -321,7 +331,8 @@ class VisualizeStatistics(AbstractCommandLineInterface):
         # 散布図
         write_obj.write_scatter_per_user()
 
-        # # CSV
+        # CSV
+        write_obj.write_whole_productivity_csv_per_date()
         write_obj.write_productivity_csv()
         write_obj.write_csv_for_task()
         write_obj.write_csv_for_annotation()
